@@ -1,12 +1,15 @@
-__version__ = "0.9.6"
+__version__ = "0.9.10"
 __package__ = "oneai"
 
-from typing_extensions import Final
+import logging
 import oneai.logger
+from typing_extensions import Final
 import oneai.skills as skills
 from oneai.classes import *
 from oneai.pipeline import Pipeline
 import oneai.clustering as clustering
+import oneai.parsing as parsing
+import oneai.util as util
 
 URL: Final[str] = "https://api.oneai.com"
 """
@@ -28,11 +31,13 @@ MAX_CONCURRENT_REQUESTS: Final[int] = 2
 Max number of allowed concurrent requests to be made by the SDK.
 Currently only enforced on `pipeline.run_batch`, other calls may be limited by the API
 """
-PRINT_PROGRESS = True
-"""
-Does nothing. Set `logging.get('oneai').propagate = False` to disable logging
-"""
 DEBUG_RAW_RESPONSES = False
 """
 Debug flag, return raw API responses instead of structured `Output` object. Only enable if you know what you're doing
 """
+DEBUG_LOG_REQUESTS = False
+"""
+Debug flag, log all requests made by the SDK.
+"""
+
+logger: logging.Logger = logging.getLogger("oneai")
