@@ -8,50 +8,8 @@ from oneai.classes import Labels, Skill, Utterance, skillclass, Output
 
 @skillclass(
     api_name="enhance",
-    is_generator=True,
-    label_type="replacement",
-    output_attr="enhanced",
-    output_attr1="replacements",
-)
-class TranscriptionEnhancer(Skill):
-    """
-    Deprecated- use `Proofread` instead
-
-    ## Output Attributes
-
-    `enhanced: Output`
-        An `Output` object containing the enhanced conversation, and output of the following `Skill`s
-    `enhanced.text: str`
-        The enhanced conversation
-    `enhanced.replacements: list[Label]`
-        A list of `Label` objects, representing changes made to the text
-
-    ## Example
-
-    >>> conversation = [oneai.Utterance(...), ...]
-    >>> pipeline = oneai.Pipeline(steps=[
-    ...     oneai.skills.TranscriptionEnhancer()
-    ... ])
-    >>> output = pipeline.run(conversation)
-    >>> output.enhanced
-    oneai.Output(text='ENHANCED TRANSCRIPTION', replacements=[...])
-    """
-
-    def __new__(cls, *args, **kwargs):
-        warn(
-            "TranscriptionEnhancer Skill is deprecated- use `Proofread` instead",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return super().__new__(cls, *args, **kwargs)
-
-
-@skillclass(
-    api_name="enhance",
-    is_generator=True,
-    label_type="replacement",
-    output_attr="proofread",
-    output_attr1="replacements",
+    text_attr="proofread",
+    labels_attr="replacements",
 )
 class Proofread(Skill):
     """
@@ -80,10 +38,8 @@ class Proofread(Skill):
 
 @skillclass(
     api_name="summarize",
-    is_generator=True,
-    label_type="origin",
-    output_attr="summary",
-    output_attr1="origins",
+    text_attr="summary",
+    labels_attr="origins",
 )
 @dataclass
 class Summarize(Skill):
@@ -123,7 +79,7 @@ class Summarize(Skill):
     find_origins: bool = False
 
 
-@skillclass(api_name="emotions", label_type="emotion")
+@skillclass(api_name="emotions")
 class Emotions(Skill):
     """
     Detects emotions in the input. Supported emotions: [`happiness`, `sadness`, `fear`, `surprise`, `anger`]
@@ -144,36 +100,7 @@ class Emotions(Skill):
     """
 
 
-@skillclass(api_name="entities", label_type="entity")
-class Entities(Skill):
-    """
-    Deprecated- use either `Names` or `Numbers` instead
-
-    ## Output Attributes
-
-    `entities: list[Label]`
-        A list of `Label` objects, with detected entities and their type
-
-    ## Example
-
-    >>> pipeline = oneai.Pipeline(steps=[
-    ...     oneai.skills.Entities()
-    ... ])
-    >>> output = pipeline.run('Jim bought shares of Acme Corp.')
-    >>> output.entities
-    [oneai.Label(type=entity, name=PERSON, span=[0, 3], value=Jim), oneai.Label(type=entity, name=ORG, span=[21, 31], value=Acme Corp.)]
-    """
-
-    def __new__(cls, *args, **kwargs):
-        warn(
-            "Entities Skill is deprecated- use either `Names` or `Numbers` instead",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return super().__new__(cls, *args, **kwargs)
-
-
-@skillclass(api_name="keywords", label_type="keyword")
+@skillclass(api_name="keywords")
 class Keywords(Skill):
     """
     Detects keywords in the input
@@ -194,7 +121,7 @@ class Keywords(Skill):
     """
 
 
-@skillclass(api_name="highlights", label_type="highlight")
+@skillclass(api_name="highlights")
 class Highlights(Skill):
     """
     Detects highlights of the input
@@ -215,7 +142,7 @@ class Highlights(Skill):
     """
 
 
-@skillclass(api_name="sentiments", label_type="sentiment")
+@skillclass(api_name="sentiments")
 class Sentiments(Skill):
     """
     Detects sentiments in the input
@@ -236,7 +163,7 @@ class Sentiments(Skill):
     """
 
 
-@skillclass(api_name="article-topics", label_type="topic", output_attr="topics")
+@skillclass(api_name="article-topics", labels_attr="topics")
 class Topics(Skill):
     """
     Detects topics of the input
@@ -258,77 +185,22 @@ class Topics(Skill):
 
 
 @skillclass(
-    api_name="extract-html",
-    is_generator=True,
-    output_attr="html_article",
+    api_name="pdf-extract-text",
+    text_attr="pdf_text",
 )
-class HTMLExtractArticle(Skill):
+class PDFExtractText(Skill):
     """
-    Extracts the main text content of an HTML page. Accepts URLs or HTML strings
+    Extracts the text from PDF files.
 
     ## Output
 
-    Main text content from the HTML page
-
-    ## Example
-
-    >>> resp = requests.get('https://oneai.com/about-us/')
-    >>> pipeline = oneai.Pipeline(steps=[
-    ...     oneai.skills.HTMLExtractArticle()
-    ... ])
-    >>> output = pipeline.run(resp.text)
-    >>> output.html_article.text[:100] + '...'
-    One AI - About us
-    ABOUT ONE AI
-    // Bringing human-level language AI to everyday life, one developer a...
+    Main text content from the PDF file
     """
 
-    def __new__(cls, *args, **kwargs):
-        warn(
-            "HTMLExtractArticle Skill is deprecated- use `HtmlToArticle` instead",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return super().__new__(cls, *args, **kwargs)
-
-
-@skillclass(
-    api_name="html-extract-text",
-    is_generator=True,
-    output_attr="html_text",
-)
-class HTMLExtractText(Skill):
-    """
-    Extracts all text content of an HTML page (including text from control elements). Accepts URLs or HTML strings. Use HTMLExtractArticle to extract the main content only
-
-    ## Output
-
-    Text content from the HTML page
-
-    ## Example
-
-    >>> resp = requests.get('https://oneai.com/about-us/')
-    >>> pipeline = oneai.Pipeline(steps=[
-    ...     oneai.skills.HTMLExtractText()
-    ... ])
-    >>> output = pipeline.run(resp.text)
-    >>> output.html_text.text[:100] + '...'
-    One AI - About usSkip to main contentAPIStudioSkillsIndustriesPricingResearchAboutAbout UsLeadership...
-    """
-
-    def __new__(cls, *args, **kwargs):
-        warn(
-            "HTMLExtractText Skill is deprecated- use `HtmlAllText` instead",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return super().__new__(cls, *args, **kwargs)
-
 
 @skillclass(
     api_name="extract-html",
-    is_generator=True,
-    output_attr="html_article",
+    text_attr="html_article",
 )
 class HtmlToArticle(Skill):
     """
@@ -354,8 +226,7 @@ class HtmlToArticle(Skill):
 
 @skillclass(
     api_name="html-extract-text",
-    is_generator=True,
-    output_attr="html_text",
+    text_attr="html_text",
 )
 class HtmlAllText(Skill):
     """
@@ -377,9 +248,7 @@ class HtmlAllText(Skill):
     """
 
 
-@skillclass(
-    api_name="action-items", label_type="action-item", output_attr="action_items"
-)
+@skillclass(api_name="action-items", labels_attr="action_items")
 class ActionItems(Skill):
     """
     ### 'Labs' Skill- this Skill is still in beta and is may produce incorrect results in some cases
@@ -404,10 +273,8 @@ class ActionItems(Skill):
 
 @skillclass(
     api_name="anonymize",
-    is_generator=True,
-    label_type="anonymized",
-    output_attr="anonymized",
-    output_attr1="anonymizations",
+    text_attr="anonymized",
+    labels_attr="anonymizations",
 )
 class Anonymize(Skill):
     """
@@ -437,10 +304,8 @@ class Anonymize(Skill):
 
 @skillclass(
     api_name="business-entities",
-    is_generator=True,
-    label_type="business-entity",
-    output_attr="labs",
-    output_attr1="pricing",
+    text_attr="labs",
+    labels_attr="pricing",
 )
 class Pricing(Skill):
     """
@@ -464,7 +329,7 @@ class Pricing(Skill):
     """
 
 
-@skillclass(api_name="names", label_type="name")
+@skillclass(api_name="names")
 @dataclass
 class Names(Skill):
     """
@@ -489,7 +354,7 @@ class Names(Skill):
     amount: Literal["more", "less", "normal"] = None
 
 
-@skillclass(api_name="numbers", label_type="number")
+@skillclass(api_name="numbers")
 class Numbers(Skill):
     """
     Detects and classifies numbers and dates in the input
@@ -509,7 +374,7 @@ class Numbers(Skill):
     """
 
 
-@skillclass(api_name="sentences", label_type="sentence")
+@skillclass(api_name="sentences")
 class SplitBySentence(Skill):
     """
     Splits input by sentence
@@ -531,8 +396,7 @@ class SplitBySentence(Skill):
 
 @skillclass(
     api_name="dialogue-segmentation",
-    label_type="dialogue-segment",
-    output_attr="segments",
+    labels_attr="segments",
 )
 @dataclass
 class SplitByTopic(Skill):
@@ -558,9 +422,7 @@ class SplitByTopic(Skill):
     use_discourse_parser: bool = False
 
 
-@skillclass(
-    api_name="sales-insights", label_type="sales-insights", output_attr="sales_insights"
-)
+@skillclass(api_name="sales-insights", labels_attr="sales_insights")
 class SalesInsights(Skill):
     """
     Splits input by discussed topics
@@ -582,8 +444,7 @@ class SalesInsights(Skill):
 
 @skillclass(
     api_name="service-email-insights",
-    label_type="service-email-insights",
-    output_attr="service_insights",
+    labels_attr="service_insights",
 )
 class ServiceInsights(Skill):
     """
@@ -606,8 +467,7 @@ class ServiceInsights(Skill):
 
 @skillclass(
     api_name="service-email-insights",
-    label_type="service-email-insights",
-    output_attr="email_insights",
+    labels_attr="email_insights",
 )
 class EmailInsights(Skill):
     """
@@ -628,9 +488,7 @@ class EmailInsights(Skill):
     """
 
 
-@skillclass(
-    api_name="detect-language", label_type="detect-language", output_attr="language"
-)
+@skillclass(api_name="detect-language", labels_attr="language")
 class DetectLanguage(Skill):
     """
     Detects language of input
@@ -650,7 +508,7 @@ class DetectLanguage(Skill):
     """
 
 
-@skillclass(api_name="headline", label_type="headline")
+@skillclass(api_name="headline")
 class Headline(Skill):
     """
     Generates a headline based on input
@@ -670,7 +528,7 @@ class Headline(Skill):
     """
 
 
-@skillclass(api_name="subheading", label_type="subheading", output_attr="subheading")
+@skillclass(api_name="subheading")
 class Subheading(Skill):
     """
     Generates a subheading based on input
@@ -692,9 +550,8 @@ class Subheading(Skill):
 
 @skillclass(
     api_name="transcribe",
-    is_generator=True,
-    output_attr="transcription",
-    output_attr1="words",
+    text_attr="transcription",
+    labels_attr="words",
 )
 @dataclass
 class Transcribe(Skill):
@@ -745,6 +602,7 @@ class OutputAttrs:
     proofread: "Output[List[Utterance]]" = None
     html_article: "Output[str]" = None
     html_text: "Output[str]" = None
+    pdf_text: "Output[str]" = None
     transcription: "Output[List[Utterance]]" = None
     anonymized: "Output" = None
     words: Labels = None
